# invenhost-core

InvenHost core integration plugin.
This plugin is required as a dependency for all other InvenHost plugins. It provides licensing and metrics functionality reuqired to fully use InvenHost plugins.

## Setup

1. Install
Install this plugin in the webinterface with the packagename `invenhost-core`

2. Enable
Enable the plugin in the plugin settings. You need to be signed in as a superuser for this.
**The server will restart if you enable the plugin**

3. Configure
// # TODO add configuration instructions

## License
This project is provided as part of InvenHost services. It follows the same license as the main InvenHost project. All rights are reserved.
(c) Copyright 2023 Matthias Mair, all rights reserved.

## Contributing
This project is not open for contributions. If you want to contribute, please contact me on code@mjmair.com.
